@@ -12,7 +12,7 @@ class WebtoonBamtokiCom(Provider, Std):
         re = self.re.compile(r'.+-(\d+).html')
         return re.search(self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
